<?php

namespace Buckhill\Model;

use Illuminate\Database\Eloquent\Model;

class ConfigModel extends Model
{
    protected $table = 'config';

    protected $fillable = ['cfg_name', 'cfg_value', 'created_at', 'updated_at'];

    public $timestamps = true;
}